Computation times — Python documentation

# Computation times

00:00.502 total execution time for auto_examples files:

Pickling (`plot_pickle.py`) | 00:00.290 | 0.0 MB
Link to other packages (`plot_numpy_matplotlib.py`) | 00:00.145 | 0.0 MB
SVG graphics (`plot_svg.py`) | 00:00.067 | 0.0 MB
Testing future statements across examples (`plot_second_future_imports.py`) | 00:00.001 | 0.0 MB
sphx_glr_auto_examples_local_module.py (`local_module.py`) | 00:00.000 | 0.0 MB